@@ -1,5 +1,5 @@
-__title__ = 'prefetch_to_dict'
-__version__ = '0.1'
+__title__ = 'peewee-utils'
+__version__='0.1.3',
 __author__ = 'Teguh Prabowo'
 __license__ = 'MIT License'
 __copyright__ = 'Copyright 2020 Teguh Prabowo'
